@@ -36,6 +36,7 @@ class LiteLLMPolicy(LLMBasePolicy):
         temperature: float = 0.2,
         max_tokens: int = 4096,
         max_tools_per_turn: Optional[int] = None,
+        base_url: Optional[str] = None,
         # LiteLLM-specific parameters
         use_caching: bool = True,
         cache_type: Literal["memory", "redis", "dual", "s3", "disk"] = "memory",
@@ -58,11 +59,14 @@ class LiteLLMPolicy(LLMBasePolicy):
             num_retries: Number of retries for failed requests
             retry_strategy: Retry strategy (literal: "exponential_backoff_retry", "constant_retry")
         """
-        super().__init__(model_id, temperature, max_tokens, max_tools_per_turn, **kwargs)
+        super().__init__(model_id, temperature, max_tokens, max_tools_per_turn, base_url, **kwargs)
 
         self.num_retries = num_retries
         self.retry_strategy = retry_strategy
 
+        # Store additional API parameters from kwargs
+        self.additional_params = kwargs
+
         # Only initialize LiteLLM in live mode (not in playback mode)
         if not self._is_playback:
             self._setup_litellm_caching(use_caching, cache_type, redis_url)
@@ -162,8 +166,17 @@ class LiteLLMPolicy(LLMBasePolicy):
             "caching": True,
             "num_retries": self.num_retries,
             "retry_strategy": self.retry_strategy,
+            "base_url": self.base_url,
         }
 
+        # Add additional parameters from kwargs (like reasoning_effort)
+        if self.additional_params:
+            request_params.update(self.additional_params)
+
+            # Tell LiteLLM to allow reasoning_effort if it's present
+            if "reasoning_effort" in self.additional_params:
+                request_params["allowed_openai_params"] = ["reasoning_effort"]
+
         # Add tools if provided
         if tools:
             request_params["tools"] = tools
@@ -183,6 +196,7 @@ class LiteLLMPolicy(LLMBasePolicy):
                 "choices": [
                     {
                         "message": {
+                            "role": response.choices[0].message.role,
                             "content": response.choices[0].message.content,
                             "tool_calls": (
                                 [
@@ -199,7 +213,8 @@ class LiteLLMPolicy(LLMBasePolicy):
                                 if response.choices[0].message.tool_calls
                                 else []
                             ),
-                        }
+                        },
+                        "finish_reason": response.choices[0].finish_reason,
                     }
                 ],
                 "usage": {
@@ -266,10 +281,19 @@ class FireworksPolicy(LiteLLMPolicy):
         super().__init__(model_id=f"fireworks_ai/{model_id}", **kwargs)
 
 
+class LocalPolicy(LiteLLMPolicy):
+    """Local policy using LiteLLM for local model endpoints."""
+
+    def __init__(self, model_id: str, base_url: str, **kwargs):
+        """Initialize LocalPolicy for local model endpoints."""
+        super().__init__(model_id=model_id, base_url=base_url, **kwargs)
+
+
 # Export the policies
 __all__ = [
     "LiteLLMPolicy",
     "OpenAIPolicy",
     "AnthropicPolicy",
     "FireworksPolicy",
+    "LocalPolicy",
 ]
