@@ -1,4 +1,6 @@
-from typing import Any, Dict, List, Optional, Union
+import os
+from datetime import datetime
+from typing import Any, Dict, List, Literal, Optional, Union
 
 from openai.types import CompletionUsage
 from openai.types.chat.chat_completion_message import (
@@ -7,12 +9,22 @@ from openai.types.chat.chat_completion_message import (
 )
 from pydantic import BaseModel, ConfigDict, Field
 
+from eval_protocol.get_pep440_version import get_pep440_version
+from eval_protocol.human_id import generate_id
+
+
+class ChatCompletionContentPartTextParam(BaseModel):
+    text: str = Field(..., description="The text content.")
+    type: Literal["text"] = Field("text", description="The type of the content part.")
+
 
 class Message(BaseModel):
     """Chat message model with trajectory evaluation support."""
 
-    role: str
-    content: Optional[str] = ""  # Content can be None for tool calls in OpenAI API
+    role: str  # assistant, user, system, tool
+    content: Optional[Union[str, List[ChatCompletionContentPartTextParam]]] = Field(
+        default="", description="The content of the message."
+    )
     name: Optional[str] = None
     tool_call_id: Optional[str] = None
     tool_calls: Optional[List[ChatCompletionMessageToolCall]] = None
@@ -180,8 +192,8 @@ class InputMetadata(BaseModel):
 
     model_config = ConfigDict(extra="allow")
 
-    row_id: Optional[str] = Field(None, description="Unique string to ID the row")
-    completion_params: CompletionParams = Field(..., description="Completion endpoint parameters used")
+    row_id: Optional[str] = Field(default_factory=generate_id, description="Unique string to ID the row")
+    completion_params: Optional[CompletionParams] = Field(None, description="Completion endpoint parameters used")
     dataset_info: Optional[Dict[str, Any]] = Field(
         None, description="Dataset row details: seed, system_prompt, environment_context, etc"
     )
@@ -190,6 +202,80 @@ class InputMetadata(BaseModel):
     )
 
 
+class EvaluationThreshold(BaseModel):
+    """Threshold configuration for evaluation tests.
+
+    The success field is required - tests must specify a minimum success rate.
+    The standard_deviation field is optional - if provided, tests must also meet the maximum standard deviation requirement.
+    """
+
+    success: float = Field(
+        ..., description="Minimum success rate threshold (fraction of total score, 0.0 to 1.0)", ge=0.0, le=1.0
+    )
+    standard_deviation: Optional[float] = Field(
+        None, description="Maximum standard deviation threshold (fraction of total score, 0.0 to 1.0)", ge=0.0, le=1.0
+    )
+
+
+class EvalMetadata(BaseModel):
+    """Metadata about the evaluation that was run."""
+
+    name: str = Field(..., description="Name of the evaluation")
+    description: Optional[str] = Field(None, description="Description of the evaluation")
+    version: str = Field(
+        default_factory=get_pep440_version,
+        description="Version of the evaluation. Should be populated with a PEP 440 version string.",
+    )
+    status: Optional[Literal["running", "finished", "error", "stopped"]] = Field(
+        None, description="Status of the evaluation"
+    )
+    num_runs: int = Field(..., description="Number of times the evaluation was repeated")
+    aggregation_method: str = Field(..., description="Method used to aggregate scores across runs")
+    passed_threshold: Optional[EvaluationThreshold] = Field(
+        None, description="Threshold configuration for test success"
+    )
+    passed: Optional[bool] = Field(None, description="Whether the evaluation passed based on the threshold")
+
+
+class ExecutionMetadata(BaseModel):
+    """Metadata about the execution of the evaluation."""
+
+    invocation_id: Optional[str] = Field(
+        default_factory=generate_id,
+        description="The ID of the invocation that this row belongs to.",
+    )
+
+    experiment_id: Optional[str] = Field(
+        default_factory=generate_id,
+        description="The ID of the experiment that this row belongs to.",
+    )
+
+    rollout_id: Optional[str] = Field(
+        default_factory=generate_id,
+        description="The ID of the rollout that this row belongs to.",
+    )
+
+    run_id: Optional[str] = Field(
+        None,
+        description=("The ID of the run that this row belongs to."),
+    )
+
+
+class RolloutStatus(BaseModel):
+    """Status of the rollout."""
+
+    """
+    running: Unfinished rollout which is still in progress.
+    finished: Rollout finished successfully.
+    error: Rollout failed.
+    stopped: Rollout terminated unexpectedly (e.g. max step, control plane signal, user stop).
+    """
+    status: Literal["running", "finished", "error"] = Field("running", description="Status of the rollout.")
+    termination_reason: Optional[str] = Field(
+        "", description="reason of the rollout status, mapped to values in TerminationReason"
+    )
+
+
 class EvaluationRow(BaseModel):
     """
     Unified data structure for a single evaluation unit that contains messages,
@@ -200,8 +286,8 @@ class EvaluationRow(BaseModel):
     supporting both row-wise batch evaluation and trajectory-based RL evaluation.
     """
 
-    # Core conversation data
-    messages: List[Message] = Field(description="List of messages in the conversation/trajectory.")
+    # Core OpenAI ChatCompletion compatible conversation data
+    messages: List[Message] = Field(description="List of messages in the conversation. Also known as a trajectory.")
 
     # Tool and function call information
     tools: Optional[List[Dict[str, Any]]] = Field(
@@ -209,8 +295,14 @@ class EvaluationRow(BaseModel):
     )
 
     # Input-related metadata (grouped together for cleaner organization)
-    input_metadata: Optional[InputMetadata] = Field(
-        default=None, description="Metadata related to the input (dataset info, model config, session data, etc.)."
+    input_metadata: InputMetadata = Field(
+        default_factory=InputMetadata,
+        description="Metadata related to the input (dataset info, model config, session data, etc.).",
+    )
+
+    rollout_status: RolloutStatus = Field(
+        default_factory=RolloutStatus,
+        description="The status of the rollout.",
     )
 
     # Ground truth reference (moved from EvaluateResult to top level)
@@ -223,11 +315,27 @@ class EvaluationRow(BaseModel):
         default=None, description="The evaluation result for this row/trajectory."
     )
 
+    execution_metadata: ExecutionMetadata = Field(
+        default_factory=ExecutionMetadata,
+        description="Metadata about the execution of the evaluation.",
+    )
+
     # LLM usage statistics
     usage: Optional[CompletionUsage] = Field(
         default=None, description="Token usage statistics from LLM calls during execution."
     )
 
+    created_at: datetime = Field(default_factory=datetime.now, description="The timestamp when the row was created.")
+
+    eval_metadata: Optional[EvalMetadata] = Field(
+        default=None, description="Metadata about the evaluation that was run."
+    )
+
+    pid: Optional[int] = Field(
+        None,
+        description="The PID of the process that created the row. This is used by the evaluation watcher to detect stopped evaluations.",
+    )
+
     def is_trajectory_evaluation(self) -> bool:
         """
         Returns True if this represents a trajectory evaluation (has step_outputs),
@@ -243,6 +351,13 @@ class EvaluationRow(BaseModel):
         """Returns the number of messages in the conversation."""
         return len(self.messages)
 
+    def get_system_message(self) -> Message:
+        """Returns the system message from the conversation. Returns empty Message if none found."""
+        system_messages = [msg for msg in self.messages if msg.role == "system"]
+        if not system_messages:
+            return Message(role="system", content="")
+        return system_messages[0]
+
     def get_assistant_messages(self) -> List[Message]:
         """Returns only the assistant messages from the conversation."""
         return [msg for msg in self.messages if msg.role == "assistant"]
@@ -419,3 +534,23 @@ class TaskDefinitionModel(BaseModel):
         # from pydantic import ConfigDict
         # model_config = ConfigDict(extra='allow')
         # For Pydantic v1, `Config.extra = "allow"` is correct.
+
+
+class MCPConfigurationServerStdio(BaseModel):
+    """Represents a MCP configuration server."""
+
+    command: str  # command to run the MCP server
+    args: List[str] = Field(default_factory=list)  # to pass to the command
+    env: List[str] = Field(default_factory=list)  # List of environment variables to verify exist in the environment
+
+
+class MCPConfigurationServerUrl(BaseModel):
+    """Represents a Remote MCP configuration server."""
+
+    url: str  # url to the MCP server
+
+
+class MCPMultiClientConfiguration(BaseModel):
+    """Represents a MCP configuration."""
+
+    mcpServers: Dict[str, Union[MCPConfigurationServerStdio, MCPConfigurationServerUrl]]
